@@ -406,3 +406,22 @@ Ext.override(Ext.form.Field, {
    
 });
 
+
+
+// We never want Windows to render larger than the browser. I can't imagine any situation
+// where this would be wanted, so this is being implemented as a global override for now:
+var orig_Window_initComponent = Ext.Window.prototype.initComponent;
+Ext.override(Ext.Window, {
+  initComponent: function() {
+
+    var browserSize = Ext.getBody().getViewSize();
+    var maxW = browserSize.width  - 10;
+    var maxH = browserSize.height - 10;
+
+    // For now, only handle the case of supplied/set height & width values:
+    if(Ext.isNumber(this.height)) { this.height = this.height < maxH ? this.height : maxH; }
+    if(Ext.isNumber(this.width))  { this.width  = this.width  < maxW ? this.width  : maxW; }
+
+    return orig_Window_initComponent.call(this);
+  }
+});
